<?php

return [
    'menu' => [
        'restAPISettings' => 'Rest API Setting',
    ],
    'fcmKey' => 'FCM Key',
    'applicationSetting' => 'Application Settings',
    'androidRestAPISettings' => 'Push Notification Setting',
    'iosRestAPISettings' => 'IOS Push Notification Setting',
    'testAndroidPushNotification' => 'Test Android Push Notification',
    'testIOSPushNotification' => 'Test IOS Push Notification',
    'sendTestPushNotification' => 'Send Test Notification',
    'devices' => 'Devices',
    'title' => 'Title',
    'message' => 'Message',
    'selectDevice' => 'Select Device',
    'notificationSentSuccessfully' => 'Push notification sent successfully',
    'noRegisterDeviceFound' => 'No registered device found',
    'howToSetIosPush' => 'IOS push notification documentation',
    'howToSetAndroidPush' => 'Android push notification documentation',
];
